import React from "react";
import {X} from "@phosphor-icons/react";
import {useCallableCurtain, useCurtains} from "../Curtains/Curtains";
import {classes, Modify} from "../../Utils";
import {useCurtain} from "../Curtains/CurtainInstance";

/**
 * More natural name of useCurtains for subapps.
 * @see useCurtains
 */
export const useSubapps = useCurtains;

/**
 * More natural name of useCurtain for subapps.
 * @see useCurtain
 */
export const useSubapp = useCurtain;

/**
 * More natural name of useCallableCurtain for subapps.
 * @see useCallableCurtain
 */
export const useCallableSubapp = useCallableCurtain;

/**
 * Subapp main component.
 */
export function Subapp({className, title, closable, children}: React.PropsWithChildren<Modify<React.HTMLAttributes<HTMLDivElement>, {
	/**
	 * Subapp title.
	 */
	title?: string;

	/**
	 * Can disable close button.
	 */
	closable?: boolean;
}>>)
{
	// Subapp is closable by default.
	closable = closable !== undefined ? closable : true;

	// Subapp state.
	const {close} = useSubapp();

	return (
		<div className={classes("subapp", className)}>
			<header>
				<h1>{title ?? ""}</h1>

				<button className={"icon-only close"} onClick={close} disabled={!closable}><X size={32}/></button>
			</header>

			<main>
				{children}
			</main>
		</div>
	);
}
